@@ -1,13 +1,10 @@
-import iso8601
-import pytz
-from tzlocal import get_localzone
 from datetime import datetime
 
 
 def parse_date(input_value):
-    if input_value is "" or input_value is None:
+    if input_value == "" or input_value is None:
         return None
-    return iso8601.parse_date(input_value)
+    return datetime.fromisoformat(input_value)
 
 
 def parse_int(input_value, default_value=None):
@@ -28,9 +25,15 @@ def parse_float(input_value, default_value=None):
         return default_value
 
 
-def localize_datetime(timestamp: datetime) -> datetime:
-    if timestamp.tzinfo is not None:
-        return timestamp
+def parse_bool_int(input_value):
+    if input_value is None:
+        return False
+    try:
+        num = int(input_value)
+        return bool(num)
+    except ValueError:
+        return False
 
-    local_tz = get_localzone()
-    return local_tz.localize(timestamp).astimezone(pytz.utc)
+
+def localize_datetime(timestamp: datetime) -> datetime:
+    return timestamp.astimezone()
